%{
  ***********************************************************************
  * Mendelssohn - Quartet nr 6                                          *
  *                                                                     *
  * encodage par J.F. Lucarelli                                         *
  * 01/01/2018 - 18/01/2018                                             *
  *                                                                     *
  * Déclaration des fonctions diverses, polyphonie,                     *
  * majuscules accentuées , ...                                         *
  *                                                                     *
  * à insérer en début des fichiers de parties ou de partitions globales*
  * pour les parties séparées                                           *
  *                                                                     *
  * Ne pas compiler                                                     *
  *                                                                     *
  ***********************************************************************
%}

\include "Common\Version.ly"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Fonction polyphonic : assure une polyphonie de type \voiceOne \new Voice \voiceTwo \oneVoice
polyphonic=
#(define-music-function (parser location voixun voixdeux)
   (ly:music? ly:music?)
   #{
     <<
       {
         \voiceOne
         $voixun
       }
       \new Voice
       {
         \voiceTwo
         $voixdeux
       }
     >>
     \oneVoice
   #}
   )

% Idem en inversant voix 1 et 2 - la voix 1, connectée à l'environnement,
% a les propriétés d'une voix 2,tournée vers le bas

polyphonicInv=
#(define-music-function (parser location voixun voixdeux)
   (ly:music? ly:music?)
   #{
     <<
       {
         \voiceTwo
         $voixun
       }
       \new Voice
       {
         \voiceOne
         $voixdeux
       }
     >>
     \oneVoice
   #}
   )

% idem en laissant libre l'orientation des hampes et liaisons -
%   utile pour introduire une ligne indépendante de nuances

polyphonicNeutral=
#(define-music-function (parser location voixun voixdeux)
   (ly:music? ly:music?)
   #{
     <<
       {
         $voixun
       }
       \new Voice
       {
         $voixdeux
       }
     >>
   #}
   )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Fonction définissant les évènements retenus dans les citations

cueEventType =
#(define-music-function
  (parser location)
  ()
  #{
    \set Score.quotedCueEventTypes =
    #'(note-event rest-event tie-event tuplet-span-event beam-event slur-event repeat-tie-event script-event
        trill-span-event phrasing-slur-event arpeggio-event tremolo-event tremolo-span-event
        laissez-vibrer-event repeat-tie-event)

  #}
  )

% Fonction supprimant les tuplets dans les citations

cueEventTypeWithoutTuplets =
#(define-music-function
  (parser location)
  ()
  #{
    \set Score.quotedCueEventTypes =
    #'(note-event rest-event tie-event beam-event slur-event repeat-tie-event script-event
        trill-span-event phrasing-slur-event arpeggio-event tremolo-event tremolo-span-event
        laissez-vibrer-event repeat-tie-event)

  #}
  )

% Supprime tous les évènements
noCueEventType =
#(define-music-function
  (parser location)
  ()
  #{
    \set Score.quotedCueEventTypes =
    #'()

  #}
  )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Imprimer un \markup sur un silence multimesure en libérant de la place horizontale

% Typiquement :
%    s4 * 0 -\tweak X-offset -3 \mSolo
%    \once \override MultiMeasureRest.minimum-length = 11
%    R1 * 16
% devient
%   \longMMR {-3 \mSolo 11 R1 * 16}
%

longMMR =
#(define-music-function (parser location offset text len lenRest) (number? ly:music? integer? ly:music?)
   #{
     s4 * 0 -\tweak X-offset $offset $text
     \once \override MultiMeasureRest.minimum-length = $len
     $lenRest
   #}
   )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Imprimer un silence multimesure de longueur donnée

% Typiquement :
%    once \override MultiMeasureRest.minimum-length = 11
%    R1 * 16
% devient
%   \longMML {11 R1 * 16}
%

longMML =
#(define-music-function (parser location len lenRest) (integer? ly:music?)
   #{
     \once \override MultiMeasureRest.minimum-length = $len
     $lenRest
   #}
   )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Mettre un soufflet entre parenthèses (ou tout autre signe)

hairpinBetweenText =
#(define-music-function (parser location leftText rightText) (markup? markup?)
   #{
     \once \override Hairpin #'stencil =
     #(lambda (grob)
        (let* ((orig (ly:grob-original grob))
               (siblings (if (ly:grob? orig)
                             (ly:spanner-broken-into orig)
                             '()))
               (hairpin-stencil (ly:stencil-aligned-to
                                 (ly:hairpin::print grob) Y CENTER))
               (left-addition (ly:stencil-aligned-to
                               (grob-interpret-markup grob leftText) Y CENTER))
               (right-addition (ly:stencil-aligned-to
                                (grob-interpret-markup grob rightText) Y CENTER)))
          (if (or (null? siblings)
                  (eq? grob (car siblings)))
              (set! hairpin-stencil
                    (ly:stencil-combine-at-edge
                     left-addition
                     X RIGHT
                     hairpin-stencil
                     0)))
          (if (or (null? siblings)
                  (eq? grob (car (reverse siblings))))
              (set! hairpin-stencil
                    (ly:stencil-combine-at-edge
                     hairpin-stencil
                     X RIGHT
                     right-addition
                     0.6)))
          hairpin-stencil))
   #})

% utilisation :
% parenthesizedHairpin = \hairpinBetweenText \markup "(" \markup ")"
% \parenthesizedHairpin
% c16\< d e f g a b c d e f g a\!
% ne vaut que pour le soufflet suivant la note concernée

%indications de volume entre soufflet
parenthesizedHairpin = \hairpinBetweenText \markup "(" \markup ")"
% idem entre crochets
bracketedHairpin = \hairpinBetweenText \markup "[" \markup "]"
shortenedHairpin = \hairpinBetweenText \markup " " \markup " "

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Guile does not deal with accented letters

%%% Use as \markup \smallCaps {Théâtre}

#(use-modules (ice-9 regex))
%%;; actually defined below, in a closure
#(define-public string-upper-case #f)
#(define accented-char-upper-case? #f)
#(define accented-char-lower-case? #f)

%%;; an accented character is seen as two characters by guile
#(let ((lower-case-accented-string "éèêëáàâäíìîïóòôöúùûüçœæ")
       (upper-case-accented-string "ÉÈÊËÁÀÂÄÍÌÎÏÓÒÔÖÚÙÛÜÇŒÆ"))
   (define (group-by-2 chars result)
     (if (or (null? chars) (null? (cdr chars)))
         (reverse! result)
         (group-by-2 (cddr chars)
           (cons (string (car chars) (cadr chars))
             result))))
   (let ((lower-case-accented-chars
          (group-by-2 (string->list lower-case-accented-string) (list)))
         (upper-case-accented-chars
          (group-by-2 (string->list upper-case-accented-string) (list))))
     (set! string-upper-case
           (lambda (str)
             (define (replace-chars str froms tos)
               (if (null? froms)
                   str
                   (replace-chars (regexp-substitute/global #f (car froms) str
                                    'pre (car tos) 'post)
                     (cdr froms)
                     (cdr tos))))
             (string-upcase (replace-chars str
                              lower-case-accented-chars
                              upper-case-accented-chars))))
     (set! accented-char-upper-case?
           (lambda (char1 char2)
             (member (string char1 char2) upper-case-accented-chars string=?)))
     (set! accented-char-lower-case?
           (lambda (char1 char2)
             (member (string char1 char2) lower-case-accented-chars string=?)))))

#(define-markup-command (smallCaps layout props text) (markup?)
   "Turn @code{text}, which should be a string, to small caps.
         @example
\\markup \\small-caps \"Text between double quotes\"
@end example"
   (define (string-list->markup strings lower)
     (let ((final-string (string-upper-case
                          (apply string-append (reverse strings)))))
       (if lower
           (markup #:fontsize -2 final-string)
           final-string)))
   (define (make-small-caps rest-chars currents current-is-lower prev-result)
     (if (null? rest-chars)
         (make-concat-markup (reverse! (cons (string-list->markup
                                              currents current-is-lower)
                                         prev-result)))
         (let* ((ch1 (car rest-chars))
                (ch2 (and (not (null? (cdr rest-chars))) (cadr rest-chars)))
                (this-char-string (string ch1))
                (is-lower (char-lower-case? ch1))
                (next-rest-chars (cdr rest-chars)))
           (cond ((and ch2 (accented-char-lower-case? ch1 ch2))
                  (set! this-char-string (string ch1 ch2))
                  (set! is-lower #t)
                  (set! next-rest-chars (cddr rest-chars)))
             ((and ch2 (accented-char-upper-case? ch1 ch2))
              (set! this-char-string (string ch1 ch2))
              (set! is-lower #f)
              (set! next-rest-chars (cddr rest-chars))))
           (if (or (and current-is-lower is-lower)
                   (and (not current-is-lower) (not is-lower)))
               (make-small-caps next-rest-chars
                 (cons this-char-string currents)
                 is-lower
                 prev-result)
               (make-small-caps next-rest-chars
                 (list this-char-string)
                 is-lower
                 (if (null? currents)
                     prev-result
                     (cons (string-list->markup
                            currents current-is-lower)
                       prev-result)))))))
   (interpret-markup layout props
     (if (string? text)
         (make-small-caps (string->list text) (list) #f (list))
         text)))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Append markup in the text property to the grob
#(define (append-markup grob old-stencil)
   (ly:stencil-combine-at-edge
    old-stencil X RIGHT (ly:text-interface::print grob)))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

trebleToBass = {
  \clef bass
  % Fake staff clef appearance
  \once \override Staff.Clef #'glyph-name = #"clefs.G"
  \once \override Staff.Clef #'Y-offset = #-1
  % Append change clef to the time signature
  \once \override Staff.TimeSignature #'text = \markup {
    \hspace #1.2
    \raise #1
    \musicglyph #"clefs.F_change"
  }
  \once \override Staff.TimeSignature #'stencil = #(lambda (grob)
                                                     (append-markup grob (ly:time-signature::print grob)))
}

bassToTreble = {
  \clef treble
  % Fake staff clef appearance
  \once \override Staff.Clef #'glyph-name = #"clefs.F"
  \once \override Staff.Clef #'Y-offset = #1
  % Append change clef to the time signature
  \once \override Staff.TimeSignature #'text = \markup {
    \hspace #1.2
    \lower #1
    \musicglyph #"clefs.G_change"
  }
  \once \override Staff.TimeSignature #'stencil = #(lambda (grob)
                                                     (append-markup grob (ly:time-signature::print grob)))
}

bassToTenor = {
  \clef tenor
  % Fake staff clef appearance
  \once \override Staff.Clef #'glyph-name = #"clefs.F"
  \once \override Staff.Clef #'Y-offset = #1
  % Append change clef to the time signature
  \once \override Staff.TimeSignature #'text = \markup {
    \hspace #1.2
    \raise #1
    \musicglyph #"clefs.C_change"
  }
  \once \override Staff.TimeSignature #'stencil = #(lambda (grob)
                                                     (append-markup grob (ly:time-signature::print grob)))
}

% passage à la clef de sol octaviée vers le bas - utile pour violoncelles

bassToTrebleOct = {
  \clef "treble_8"
  % Fake staff clef appearance
  \once \override Staff.Clef #'glyph-name = #"clefs.F"
  \once \override Staff.Clef #'Y-offset = #1
  % Append change clef to the time signature
  \once \override Staff.TimeSignature #'text = \markup {
    \hspace #1.2
    \raise #1
    \musicglyph #"clefs.G_change"
  }
  \once \override Staff.TimeSignature #'stencil = #(lambda (grob)
                                                     (append-markup grob (ly:time-signature::print grob)))
}

% Macro \columns pour écrire un texte multi-colonnes
% Usage : remplacer \fill-line par \columns

#(define-markup-command (columns layout props args) (markup-list?)
   (let ((line-width (/ (chain-assoc-get 'line-width props
                          (ly:output-def-lookup layout 'line-width))
                       (max (length args) 1))))
     (interpret-markup layout props
       (make-line-markup (map (lambda (line)
                                (markup #:pad-to-box `(20 . ,line-width) '(0 . 0)
                                  #:override `(line-width . ,line-width)
                                  line))
                           args)))))

% Fonction elseTag à utiliser avec
%\tag #' ...
%\elesTag ...

% improbable name ...
elseTagName = #(gensym)

%% elseTag defines two symbols for property 'tags of the music
elseTag =
#(define-music-function (parser location tag arg)(symbol? ly:music?)
   (set! (ly:music-property arg 'tags)
         (cons tag (cons elseTagName (ly:music-property arg 'tags))))
   arg)

%% this redefinition of keepWithTag verifies that the music has NOT at the same
%% time the symbol "tag" and "elseTagName" (above) in its 'tags property
keepWithTag =
#(define-music-function (parser location tag music) (symbol? ly:music?)
   (music-filter
    (lambda (m)
      (let* ((tags (ly:music-property m 'tags))
             (resA (memq tag tags))
             (resB (memq elseTagName tags)))
        (or (eq? tags '())
            (and (not (equal? resA #f))
                 (equal? resB #f))
            (and (not (equal? resB #f))
                 (equal? resA #f)))))
    music))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Fonction forcePercent - permet la numérotation des répétitions à partir de 1

forcePercent =
#(define-music-function (parser location mus) (ly:music?)
   (let ((percent (make-music 'PercentEvent
                    'repeat-count 1
                    'length (ly:music-length mus))))

     (make-event-chord (list percent))))

% Ne fonctionne pas correctement dans cette configuration

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Fonction tongue - articulation sur des tremolo

%\relative c' {
%  \tuplet 3/2 { \repeat tremolo 3 c8-\tongue #3 }
% }

tongue =
#(define-music-function (parser location dots) (integer?)
   (let ((script (make-music 'ArticulationEvent
                   'articulation-type "staccato")))
     (set! (ly:music-property script 'tweaks)
           (acons 'stencil
             (lambda (grob)
               (let ((stil (ly:script-interface::print grob)))
                 (let loop ((count (1- dots)) (new-stil stil))
                   (if (> count 0)
                       (loop (1- count)
                         (ly:stencil-combine-at-edge new-stil X RIGHT stil 0.2))
                       (ly:stencil-aligned-to new-stil X CENTER)))))
             (ly:music-property script 'tweaks)))
     script))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% showMultiRests - hideMultiTests
% Cache ou affiche les silences multi-mesure
% Permet le masquage des portées vides.
% Utilisation avec \RemoveEmptyStaves dans la construction des portées.
% Utilisation : \tag #'conductorScore \showMultiRests empêche les silences multi-mesure de cacher la portée
% hideMultiRests : retourne au comportement par défaut

showMultiRests = {
  \set Staff.keepAliveInterfaces = #'(
                                       rhythmic-grob-interface
                                       multi-measure-rest-interface
                                       lyric-interface
                                       stanza-number-interface
                                       percent-repeat-interface)
}

hideMultiRests = \unset Staff.keepAliveInterfaces

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Credit: David Nalesnik
%% The following is a lot of code duplicated from program files (as
%% none of these functions is public).

#(define (make-bezier-sandwich-stencil coords thick xext yext)
   (let* ((command-list `(moveto
                          ,(car (list-ref coords 3))
                          ,(cdr (list-ref coords 3))
                          curveto
                          ,(car (list-ref coords 0))
                          ,(cdr (list-ref coords 0))
                          ,(car (list-ref coords 1))
                          ,(cdr (list-ref coords 1))
                          ,(car (list-ref coords 2))
                          ,(cdr (list-ref coords 2))
                          curveto
                          ,(car (list-ref coords 4))
                          ,(cdr (list-ref coords 4))
                          ,(car (list-ref coords 5))
                          ,(cdr (list-ref coords 5))
                          ,(car (list-ref coords 6))
                          ,(cdr (list-ref coords 6))
                          closepath)))
     (ly:make-stencil
      `(path ,thick `(,@' ,command-list) 'round 'round #t)
      xext
      yext)))

#(define (make-parenthesis-stencil
          y-extent half-thickness width angularity)
   "Create a parenthesis stencil.
@var{y-extent} is the Y extent of the markup inside the parenthesis.
@var{half-thickness} is the half thickness of the parenthesis.
@var{width} is the width of a parenthesis.
The higher the value of number @var{angularity},
the more angular the shape of the parenthesis."
   (let* ((line-width 0.1)
          ;; Horizontal position of baseline that end points run through.
          (base-x
           (if (< width 0)
               (- width)
               0))
          ;; X value farthest from baseline on outside  of curve
          (outer-x (+ base-x width))
          ;; X extent of bezier sandwich centerline curves
          (x-extent (ordered-cons base-x outer-x))
          (bottom-y (interval-start y-extent))
          (top-y (interval-end y-extent))

          (lower-end-point (cons base-x bottom-y))
          (upper-end-point (cons base-x top-y))

          (outer-control-x (+ base-x (* 4/3 width)))
          (inner-control-x (+ outer-control-x
                             (if (< width 0)
                                 half-thickness
                                 (- half-thickness))))

          ;; Vertical distance between a control point
          ;; and the end point it connects to.
          (offset-index (- (* 0.6 angularity) 0.8))
          (lower-control-y (interval-index y-extent offset-index))
          (upper-control-y (interval-index y-extent (- offset-index)))

          (lower-outer-control-point
           (cons outer-control-x lower-control-y))
          (upper-outer-control-point
           (cons outer-control-x upper-control-y))
          (upper-inner-control-point
           (cons inner-control-x upper-control-y))
          (lower-inner-control-point
           (cons inner-control-x lower-control-y)))

     (make-bezier-sandwich-stencil
      (list
       ;; Step 4: curve through inner control points
       ;; to lower end point.
       upper-inner-control-point
       lower-inner-control-point
       lower-end-point
       ;; Step 3: move to upper end point.
       upper-end-point
       ;; Step 2: curve through outer control points
       ;; to upper end point.
       lower-outer-control-point
       upper-outer-control-point
       upper-end-point
       ;; Step 1: move to lower end point.
       lower-end-point)
      line-width
      (interval-widen x-extent (/ line-width 2))
      (interval-widen y-extent (/ line-width 2)))))

#(define-public (parenthesize-stencil
                 stencil half-thickness width angularity padding)
   "Add parentheses around @var{stencil}, returning a new stencil."
   (let* ((y-extent (ly:stencil-extent stencil Y))
          (lp (make-parenthesis-stencil
               y-extent half-thickness (- width) angularity))
          (rp (make-parenthesis-stencil
               y-extent half-thickness width angularity)))
     (set! stencil (ly:stencil-combine-at-edge lp X RIGHT stencil padding))
     (set! stencil (ly:stencil-combine-at-edge stencil X RIGHT rp padding))
     stencil))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END QUOTED CODE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#(define (parenthesize-slur half-thickness width angularity padding)
   (lambda (grob)
     (let* ((stil (ly:slur::print grob))
            (cps (ly:grob-property grob 'control-points))
            (extent-L (cons (- (cdr (first cps)) 0.5)
                        (+ (cdr (first cps)) 0.5)))
            (extent-R (cons (- (cdr (last cps)) 0.5)
                        (+ (cdr (last cps)) 0.5)))
            (left-par (make-parenthesis-stencil
                       extent-L half-thickness (- width) angularity))
            (right-par (make-parenthesis-stencil
                        extent-R half-thickness width angularity))
            (stil (ly:stencil-combine-at-edge left-par X RIGHT stil padding))
            (stil (ly:stencil-combine-at-edge stil X RIGHT right-par padding)))
       stil)))

parenthesizeSlur =
#(define-music-function (parser location half-thickness width angularity padding)
   (number? number? number? number?)
   #{
     \once \override Slur.stencil = #(parenthesize-slur half-thickness width angularity padding)
   #})

myParSlur = \parenthesizeSlur #0.05 #0.25 #0 #0.5

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END FUNCTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% EXAMPLE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%{
\relative c'' {
  \myParSlur
  % I'm using \shape to move the slur up a uniform amount so that parentheses
  % don't bump into note.
  \shape #'((0 . 0.5) (0 . 0.5) (0 . 0.5) (0 . 0.5)) Slur
  c-( d e f)
  \myParSlur
  \shape #'((0 . -0.5) (0 . -0.5) (0 . -0.5) (0 . -0.5)) Slur
  c,( d e f)
}
%}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Fonction markStaff : équivalent à mark, mais relatif au contexte \staff, et non à \score

% Grand merci à Gilles Thibault

markStaff =
#(define-music-function
  (parser location label) ((scheme? '()))
  "Make the music for the \\mark command."
  (let* ((set (and (integer? label)
                   (context-spec-music (make-property-set 'rehearsalMark label)
                     'Staff)))
         (ev (make-music 'MarkEvent
               'origin location)))

    (if set
        (make-sequential-music (list set ev))
        (begin
         (set! (ly:music-property ev 'label) label)
         ev))))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Couper le nom d'instrument selon les césures

#(define (general-column align-dir baseline mols)
   (let* ((aligned-mols (map (lambda (x) (ly:stencil-aligned-to x X align-dir)) mols)))
     (stack-lines -1 0.0 baseline aligned-mols)))

#(define-markup-command (textCenter layout props args)(markup-list?)
   #:properties ((baseline-skip))
   (general-column CENTER baseline-skip (wordwrap-internal-markup-list layout props #f args)))

shortIncipit =
#(define-music-function (parser location InstrName ) (markup?)
   #{
     \set Staff.instrumentName = \markup {
       \override #'(line-width . 12)
       #InstrName
     }
   #})
%{
myInst = \markup\textCenter { Cantus primi chori }

{ \shortIncipit\myInst c' }
%}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

transposedCueDuringWithClef =
#(define-music-function
  (parser location what dir pitch clef main-music)
  (string? ly:dir? ly:pitch? string? ly:music?)
  (_i "Combine cueDuringWithClef and transposedCueDuring.")
  (make-music 'QuoteMusic
    'element main-music
    'quoted-context-type 'CueVoice
    'quoted-context-id "cue"
    'quoted-music-name what
    'quoted-music-clef clef
    'quoted-voice-direction dir
    'quoted-transposition pitch))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fonction newSpacingIn : entrée dans une section d'espacement horizontal réduit
% Utile dans les citations
% La valeur 0.5 pour l'espacement constitue un bon compromis

newSpacingIn =
#(define-music-function
  (parser location)
  ()
  #{
    \newSpacingSection
    \override Score.SpacingSpanner.spacing-increment = 0.5
  #}
  )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fonction newSpacingOut : sortie d'une section d'espacement horizontal réduit
% Utile dans les citations

newSpacingOut =
#(define-music-function
  (parser location)
  ()
  #{
    \newSpacingSection
    \revert Score.SpacingSpanner.spacing-increment
  #}
  )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fonction cueWithPartial
%
% permet de faire commencer une citation sur le silence MM précédent
%{
  cueWithPartial =
  #(define-music-function (parser location voixun voixdeux)
    (ly:music? ly:music?)
    #{
      \once \override MultiMeasureRest.expand-limit = 1
      \once \override MultiMeasureRestNumber.transparent = ##t
      \once \override MultiMeasureRest.X-offset = 3
      \once \override Voice.MultiMeasureRest.minimum-length = 0
      s4 * 0 -\tweak outside-staff-priority 0 -\tweak X-offset 3.5
      ^\markup {\bold \concat {\musicglyph #"one" \musicglyph #"zero"}}
      R1*9
      \once \override Voice.MultiMeasureRest.minimum-length = 0
      \once \override Score.BarLine.transparent = ##t
      \once \override Score.MultiMeasureRest.transparent = ##t
      \once \override Score.MultiMeasureRestNumber.transparent = ##t
    #}
%}
